@@ -1,26 +1,34 @@
 """`column.py` houses the main `PyColumn` and `PyColumns` class.
+
 Once connected to your model, interacting with column(s) will be done through these classes.
 """
 import logging
 import pandas as pd
-from object import PyObject, PyObjects
+from pytabular.object import PyObject, PyObjects
 from Microsoft.AnalysisServices.Tabular import ColumnType
 
 logger = logging.getLogger("PyTabular")
 
 
 class PyColumn(PyObject):
-    """Wrapper for [Column](https://learn.microsoft.com/en-us/dotnet/api/microsoft.analysisservices.tabular.column?view=analysisservices-dotnet).
-    With a few other bells and whistles added to it.
+    """The main class to work with your columns.
+
     Notice the `PyObject` magic method `__getattr__()` will search in `self._object`
     if it is unable to find it in the default attributes.
     This let's you also easily check the default .Net properties.
-
-    Args:
-        Table: Parent Table to the Column
+    See methods for extra functionality.
     """
 
     def __init__(self, object, table) -> None:
+        """Init that connects your column to parent table.
+
+        It will also build custom rows for your `rich`
+        display table.
+
+        Args:
+            object (Column): .Net column object.
+            table (Table): .Net table object.
+        """
         super().__init__(object)
         self.Table = table
         self._display.add_row(
@@ -36,9 +44,10 @@ class PyColumn(PyObject):
         self._display.add_row("DisplayFolder", str(self._object.DisplayFolder))
 
     def get_dependencies(self) -> pd.DataFrame:
-        """Returns the dependant columns of a measure"""
-        dmv_query = f"select * from $SYSTEM.DISCOVER_CALC_DEPENDENCY where [OBJECT] = '{self.Name}' and [TABLE] = '{self.Table.Name}'"
-        return self.Table.Model.Query(dmv_query)
+        """Returns the dependant columns of a measure."""
+        dmv_query = f"select * from $SYSTEM.DISCOVER_CALC_DEPENDENCY where [OBJECT] = \
+            '{self.Name}' and [TABLE] = '{self.Table.Name}'"
+        return self.Table.Model.query(dmv_query)
 
     def get_sample_values(self, top_n: int = 3) -> pd.DataFrame:
         """Get sample values of column."""
@@ -52,13 +61,14 @@ class PyColumn(PyObject):
                                     0,
                                     FILTER(
                                         VALUES({column_to_sample}),
-                                        NOT ISBLANK({column_to_sample}) && LEN({column_to_sample}) > 0
+                                        NOT ISBLANK({column_to_sample})
+                                        && LEN({column_to_sample}) > 0
                                     ),
                                     1
                                 )
                                 ORDER BY {column_to_sample}
                         """
-            return self.Table.Model.Query(dax_query)
+            return self.Table.Model.query(dax_query)
         except Exception:
             # This is really tech debt anyways and should be replaced...
             dax_query = f"""
@@ -71,52 +81,64 @@ class PyColumn(PyObject):
                     )
                 )
             """
-            return self.Table.Model.Query(dax_query)
+            return self.Table.Model.query(dax_query)
 
-    def Distinct_Count(self, No_Blank=False) -> int:
-        """Get [DISTINCTCOUNT](https://learn.microsoft.com/en-us/dax/distinctcount-function-dax) of Column.
+    def distinct_count(self, no_blank=False) -> int:
+        """Get the `DISTINCTCOUNT` of a column.
 
         Args:
-            No_Blank (bool, optional): Ability to call [DISTINCTCOUNTNOBLANK](https://learn.microsoft.com/en-us/dax/distinctcountnoblank-function-dax). Defaults to False.
+            no_blank (bool, optional): If `True`, will call `DISTINCTCOUNTNOBLANK`.
+                Defaults to `False`.
 
         Returns:
-            int: Number of Distinct Count from column. If `No_Blank == True` then will return number of Distinct Count no blanks.
+            int: Number of Distinct Count from column.
+                If `no_blank == True` then will return number of distinct count no blanks.
         """
         func = "DISTINCTCOUNT"
-        if No_Blank:
+        if no_blank:
             func += "NOBLANK"
-        return self.Table.Model.Adomd.Query(
+        return self.Table.Model.Adomd.query(
             f"EVALUATE {{{func}('{self.Table.Name}'[{self.Name}])}}"
         )
 
-    def Values(self) -> pd.DataFrame:
-        """Get single column DataFrame of [VALUES](https://learn.microsoft.com/en-us/dax/values-function-dax)
+    def values(self) -> pd.DataFrame:
+        """Get single column DataFrame of values in column.
+
+        Similar to `get_sample_values()` but will return **all**.
 
         Returns:
-            pd.DataFrame: Single Column DataFrame of Values.
+            pd.DataFrame: Single column DataFrame of values.
         """
-        return self.Table.Model.Adomd.Query(
+        return self.Table.Model.Adomd.query(
             f"EVALUATE VALUES('{self.Table.Name}'[{self.Name}])"
         )
 
 
 class PyColumns(PyObjects):
-    """Groups together multiple columns. See `PyObjects` class for what more it can do.
+    """Groups together multiple `PyColumn()`.
+
+    See `PyObjects` class for what more it can do.
     You can interact with `PyColumns` straight from model. For ex: `model.Columns`.
     Or through individual tables `model.Tables[TABLE_NAME].Columns`.
-    You can even filter down with `.Find()`. For example find all columns with `Key` in name.
+    You can even filter down with `.Find()`.
+    For example find all columns with `Key` in name.
     `model.Columns.Find('Key')`.
     """
 
     def __init__(self, objects) -> None:
+        """Init extends through to the `PyObjects()` init."""
         super().__init__(objects)
 
-    def Query_All(self, query_function: str = "COUNTROWS(VALUES(_))") -> pd.DataFrame:
-        """This will dynamically create a query to pull all columns from the model and run the query function.
-        It will replace the _ with the column to run.
+    def query_all(self, query_function: str = "COUNTROWS(VALUES(_))") -> pd.DataFrame:
+        """This will dynamically all columns in `PyColumns()` class.
+
+        It will replace the `_` with the column to run
+        whatever the given `query_function` value is.
 
         Args:
-                query_function (str, optional): Dax query is dynamically building a query with the UNION & ROW DAX Functions.
+                query_function (str, optional): Default is `COUNTROWS(VALUES(_))`.
+                        The `_` gets replaced with the column in question.
+                        Method will take whatever DAX query is given.
 
         Returns:
                 pd.DataFrame: Returns dataframe with results.
@@ -131,6 +153,8 @@ class PyColumns(PyObjects):
                 table_name = column.Table.get_Name()
                 column_name = column.get_Name()
                 dax_identifier = f"'{table_name}'[{column_name}]"
-                query_str += f"ROW(\"Table\",\"{table_name}\",\"Column\",\"{column_name}\",\"{query_function}\",{query_function.replace('_',dax_identifier)}),\n"
+                query_str += f"ROW(\"Table\",\"{table_name}\",\
+                    \"Column\",\"{column_name}\",\"{query_function}\",\
+                    {query_function.replace('_',dax_identifier)}),\n" # noqa: E231, E261
         query_str = f"{query_str[:-2]})"
-        return self[0].Table.Model.Query(query_str)
+        return self[0].Table.Model.query(query_str)
